<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">

<head>
  <title>ktorrent - web interface</title>
  <link rel="stylesheet" href="style.css" type="text/css" />
  <meta name="GENERATOR" content="Quanta Plus" />
  <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />

</head>
<body>


<div id="action" style="min-height : 130px;">
	<img src="icon.png" alt="" style="float : left; border : 0px solid;" />
	<span style="font-size : x-large; margin-left : 50px;">Goodbye!</span>
</div>

</form>
</body>
</html>
