/* styles for login.html */

body {
	background: url(ktorrentwebinterfacelogo.png) no-repeat 120px 120px;
	font-family: verdana, arial, sans-serif;
	color: #000000;
	font-size: 12px;
}

input, textarea {
	border: 1px solid #000000;
	width: 120px;
}
